@@ -1,4 +1,5 @@
 """Downloader Tests"""
+
 import copy
 import re
 from collections import OrderedDict
@@ -113,14 +114,29 @@ class TestDownloader:
         assert abspath(path) == abspath(join(downloaderfolder, filename))
 
     def test_init(self, monkeypatch, downloaderfolder):
-        basicauthfile = join(downloaderfolder, "basicauth.txt")
         with Download(auth=("u", "p")) as downloader:
             assert downloader.session.auth == ("u", "p")
         basicauth = "Basic dXNlcjpwYXNz"
         with Download(basic_auth=basicauth) as downloader:
             assert downloader.session.auth == ("user", "pass")
+        basicauthfile = join(downloaderfolder, "basicauth.txt")
         with Download(basic_auth_file=basicauthfile) as downloader:
             assert downloader.session.auth == ("testuser", "testpass")
+        bearertoken = "ABCDE"
+        with Download(bearer_token=bearertoken) as downloader:
+            assert downloader.session.headers["Accept"] == "application/json"
+            assert (
+                downloader.session.headers["Authorization"]
+                == f"Bearer {bearertoken}"
+            )
+        bearertokenfile = join(downloaderfolder, "bearertoken.txt")
+        bearertoken = "12345"
+        with Download(bearer_token_file=bearertokenfile) as downloader:
+            assert downloader.session.headers["Accept"] == "application/json"
+            assert (
+                downloader.session.headers["Authorization"]
+                == f"Bearer {bearertoken}"
+            )
         extraparamsyamltree = join(downloaderfolder, "extra_params_tree.yaml")
         with Download(
             extra_params_yaml=extraparamsyamltree, extra_params_lookup="mykey"
@@ -129,6 +145,27 @@ class TestDownloader:
         monkeypatch.setenv("BASIC_AUTH", basicauth)
         with Download() as downloader:
             assert downloader.session.auth == ("user", "pass")
+        bearertoken = "98765"
+        monkeypatch.setenv("BEARER_TOKEN", bearertoken)
+        with pytest.raises(SessionError):
+            Download()
+        with Download(use_auth="bearer_token") as downloader:
+            assert downloader.session.headers["Accept"] == "application/json"
+            assert (
+                downloader.session.headers["Authorization"]
+                == f"Bearer {bearertoken}"
+            )
+        with Download(use_auth="basic_auth") as downloader:
+            assert downloader.session.auth == ("user", "pass")
+        monkeypatch.delenv("BASIC_AUTH")
+        with Download() as downloader:
+            assert downloader.session.headers["Accept"] == "application/json"
+            assert (
+                downloader.session.headers["Authorization"]
+                == f"Bearer {bearertoken}"
+            )
+        monkeypatch.delenv("BEARER_TOKEN")
+        monkeypatch.setenv("BASIC_AUTH", basicauth)
         with pytest.raises(SessionError):
             Download(basic_auth="12345")
         with pytest.raises(SessionError):
@@ -159,6 +196,20 @@ class TestDownloader:
                 extra_params_yaml=extraparamsyamltree,
                 extra_params_lookup="mykey",
             )
+        with Download(
+            auth=("u", "p"),
+            extra_params_yaml=extraparamsyamltree,
+            extra_params_lookup="mykey",
+            use_auth="basic_auth",
+        ) as downloader:
+            assert downloader.session.auth == ("testuser", "testpass")
+        with Download(
+            auth=("u", "p"),
+            extra_params_yaml=extraparamsyamltree,
+            extra_params_lookup="mykey",
+            use_auth="auth",
+        ) as downloader:
+            assert downloader.session.auth == ("u", "p")
         with pytest.raises(SessionError):
             Download(
                 basic_auth_file=basicauthfile,
@@ -172,6 +223,8 @@ class TestDownloader:
             )
         with pytest.raises(IOError):
             Download(basic_auth_file="NOTEXIST")
+        with pytest.raises(IOError):
+            Download(bearer_token_file="NOTEXIST")
         extraparamsyaml = join(downloaderfolder, "extra_params.yaml")
         test_url = "http://www.lalala.com/lala"
         with Download(
@@ -225,6 +278,22 @@ class TestDownloader:
             assert "param3=11" in full_url
             assert "basic_auth" not in full_url
         monkeypatch.delenv("EXTRA_PARAMS")
+        bearertoken = "ZYXWV"
+        with Download(
+            extra_params_dict={"bearer_token": bearertoken}
+        ) as downloader:
+            assert downloader.session.headers["Accept"] == "application/json"
+            assert (
+                downloader.session.headers["Authorization"]
+                == f"Bearer {bearertoken}"
+            )
+            bearertoken = "FGHIJ"
+            downloader.set_bearer_token(bearertoken)
+            assert (
+                downloader.session.headers["Authorization"]
+                == f"Bearer {bearertoken}"
+            )
+
         with pytest.raises(SessionError):
             Download(
                 extra_params_dict={"key1": "val1"},
@@ -338,7 +407,7 @@ class TestDownloader:
         with Download() as downloader:
             downloader.setup(fixtureurl)
             md5hash = downloader.hash_stream(fixtureurl)
-            assert md5hash == "da9db35a396cca10c618f6795bdb9ff2"
+            assert md5hash == "da52e60d7a7c541e6fa67076bfac49f8"
 
     def test_download_file(
         self,
@@ -403,7 +472,7 @@ class TestDownloader:
                 filename=filename,
             )
             fpath = abspath(f)
-            with open(fpath) as fi:
+            with open(fpath, encoding="utf-8") as fi:
                 text = fi.read()
                 assert '"id": "10"' in text
                 assert '"lala": "a"' in text
@@ -419,7 +488,7 @@ class TestDownloader:
                 filename=filename,
             )
             fpath = abspath(f)
-            with open(fpath) as fi:
+            with open(fpath, encoding="utf-8") as fi:
                 text = fi.read()
                 assert '"id": "3"' in text
                 assert '"lala": "b"' in text
@@ -457,7 +526,6 @@ class TestDownloader:
 615,2229RTA,,19/04/2001,2001,1,Riots/Protests,Rioters (Algeria),Berber Ethnic Group (Algeria),5,Police Forces of Algeria (1999-),,1,15,Algeria,Tizi Ouzou,Tizi Ouzou,,Tizi Ouzou,36.71183,4.04591,3,Kabylie report,"Riots were reported in numerous villages in Kabylie, resulting in dozens wounded in clashes between protesters and police and significant material damage.",0
 615,2230RTA,,20/04/2001,2001,1,Riots/Protests,Protesters (Algeria),Students (Algeria),6,,,0,60,Algeria,Bejaia,Amizour,,Amizour,36.64022,4.90131,1,Crisis Group,Students protested in the Amizour area. At least 3 were later arrested for allegedly insulting gendarmes.,0
 615,2231RTA,,21/04/2001,2001,1,Riots/Protests,Rioters (Algeria),Berber Ethnic Group (Algeria),5,Police Forces of Algeria (1999-),,1,15,Algeria,Bejaia,Amizour,,Amizour,36.64022,4.90131,1,Kabylie report,"Rioters threw molotov cocktails, rocks and burning tires at gendarmerie stations in Beni Douala, El-Kseur and Amizour.",0
-
 """
             )
             downloader.download(
